"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.SquircleView = SquircleView;
Object.defineProperty(exports, "getSvgPath", {
  enumerable: true,
  get: function () {
    return _figmaSquircle.getSvgPath;
  }
});

var React = _interopRequireWildcard(require("react"));

var _reactNative = require("react-native");

var _reactNativeSvg = _interopRequireWildcard(require("react-native-svg"));

var _figmaSquircle = require("figma-squircle");

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function SquircleView({
  squircleParams,
  children,
  ...rest
}) {
  return /*#__PURE__*/React.createElement(_reactNative.View, rest, /*#__PURE__*/React.createElement(SquircleBackground, squircleParams), children);
}

function SquircleBackground({
  cornerRadius = 0,
  topLeftCornerRadius,
  topRightCornerRadius,
  bottomRightCornerRadius,
  bottomLeftCornerRadius,
  cornerSmoothing,
  fillColor = '#000',
  strokeColor = '#000',
  strokeWidth = 0
}) {
  return /*#__PURE__*/React.createElement(Rect, {
    style: _reactNative.StyleSheet.absoluteFill
  }, ({
    width,
    height
  }) => {
    const squirclePath = (0, _figmaSquircle.getSvgPath)({
      width,
      height,
      cornerSmoothing,
      cornerRadius,
      topLeftCornerRadius,
      topRightCornerRadius,
      bottomRightCornerRadius,
      bottomLeftCornerRadius
    });
    const hasStroke = strokeWidth > 0;

    if (!hasStroke) {
      return /*#__PURE__*/React.createElement(_reactNativeSvg.default, {
        width: width,
        height: height
      }, /*#__PURE__*/React.createElement(_reactNativeSvg.Path, {
        d: squirclePath,
        fill: fillColor
      }));
    } else {
      // Since SVG doesn't support inner stroke, we double the stroke width
      // and remove the outer half with clipPath
      return /*#__PURE__*/React.createElement(_reactNativeSvg.default, {
        width: width,
        height: height
      }, /*#__PURE__*/React.createElement(_reactNativeSvg.Defs, null, /*#__PURE__*/React.createElement(_reactNativeSvg.ClipPath, {
        id: "clip"
      }, /*#__PURE__*/React.createElement(_reactNativeSvg.Path, {
        d: squirclePath
      }))), /*#__PURE__*/React.createElement(_reactNativeSvg.Path, {
        clipPath: "url(#clip)",
        d: squirclePath,
        fill: fillColor,
        stroke: strokeColor,
        strokeWidth: strokeWidth * 2
      }));
    }
  });
} // Inspired by https://reach.tech/rect/


function Rect({
  children,
  ...rest
}) {
  const [rect, setRect] = (0, React.useState)(null);
  return /*#__PURE__*/React.createElement(_reactNative.View, _extends({}, rest, {
    onLayout: e => {
      setRect({
        width: e.nativeEvent.layout.width,
        height: e.nativeEvent.layout.height
      });
    }
  }), rect ? children(rect) : null);
}
//# sourceMappingURL=index.js.map